@@ -73,7 +73,6 @@ def _stage_file(path, fs, name, odb=None, upload_odb=None, dry_run=False):
     else:
         odb.add(path, fs, oid, hardlink=False)
         obj = odb.get(oid)
-        obj.hash_info = hash_info
 
     return path, meta, obj
 
@@ -162,10 +161,6 @@ def _stage_tree(path, fs, fs_info, name, odb=None, **kwargs):
     tree.digest()
     odb.add(tree.path, tree.fs, tree.oid, hardlink=False)
     raw = odb.get(tree.oid)
-    # cleanup unneeded memfs tmpfile and return tree based on the
-    # ODB fs/path
-    if odb.fs != tree.fs:
-        tree.fs.remove(tree.path)
     tree.fs = raw.fs
     tree.path = raw.path
     return meta, tree
@@ -204,7 +199,7 @@ def _get_staging(odb: "HashFileDB") -> "ReferenceHashFileDB":
     fs = MemoryFileSystem()
     path = _make_staging_url(fs, odb, odb.path)
     state = odb.state
-    return ReferenceHashFileDB(fs, path, state=state)
+    return ReferenceHashFileDB(fs, path, state=state, hash_name=odb.hash_name)
 
 
 def _stage_external_tree_info(odb, tree, name):
